==> we-node-client-grpc-java-0.3.0-sources.jar: com/wavesenterprise/protobuf/service/util/NodeInfoServiceGrpc.java <==
package com.wavesenterprise.protobuf.service.util;

import static io.grpc.MethodDescriptor.generateFullMethodName;
import static io.grpc.stub.ClientCalls.asyncBidiStreamingCall;
import static io.grpc.stub.ClientCalls.asyncClientStreamingCall;
import static io.grpc.stub.ClientCalls.asyncServerStreamingCall;
import static io.grpc.stub.ClientCalls.asyncUnaryCall;
import static io.grpc.stub.ClientCalls.blockingServerStreamingCall;
import static io.grpc.stub.ClientCalls.blockingUnaryCall;
import static io.grpc.stub.ClientCalls.futureUnaryCall;
import static io.grpc.stub.ServerCalls.asyncBidiStreamingCall;
import static io.grpc.stub.ServerCalls.asyncClientStreamingCall;
import static io.grpc.stub.ServerCalls.asyncServerStreamingCall;
import static io.grpc.stub.ServerCalls.asyncUnaryCall;
import static io.grpc.stub.ServerCalls.asyncUnimplementedStreamingCall;
import static io.grpc.stub.ServerCalls.asyncUnimplementedUnaryCall;

/**
 */
@javax.annotation.Generated(
    value = "by gRPC proto compiler (version 1.16.0)",
    comments = "Source: util/util_node_info_service.proto")
public final class NodeInfoServiceGrpc {

  private NodeInfoServiceGrpc() {}

  public static final String SERVICE_NAME = "wavesenterprise.NodeInfoService";

  // Static method descriptors that strictly reflect the proto.
  private static volatile io.grpc.MethodDescriptor<com.google.protobuf.Empty,
      com.wavesenterprise.protobuf.service.util.NodeConfigResponse> getNodeConfigMethod;

  @io.grpc.stub.annotations.RpcMethod(
      fullMethodName = SERVICE_NAME + '/' + "NodeConfig",
      requestType = com.google.protobuf.Empty.class,
      responseType = com.wavesenterprise.protobuf.service.util.NodeConfigResponse.class,
      methodType = io.grpc.MethodDescriptor.MethodType.UNARY)
  public static io.grpc.MethodDescriptor<com.google.protobuf.Empty,
      com.wavesenterprise.protobuf.service.util.NodeConfigResponse> getNodeConfigMethod() {
    io.grpc.MethodDescriptor<com.google.protobuf.Empty, com.wavesenterprise.protobuf.service.util.NodeConfigResponse> getNodeConfigMethod;
    if ((getNodeConfigMethod = NodeInfoServiceGrpc.getNodeConfigMethod) == null) {
      synchronized (NodeInfoServiceGrpc.class) {
        if ((getNodeConfigMethod = NodeInfoServiceGrpc.getNodeConfigMethod) == null) {
          NodeInfoServiceGrpc.getNodeConfigMethod = getNodeConfigMethod = 
              io.grpc.MethodDescriptor.<com.google.protobuf.Empty, com.wavesenterprise.protobuf.service.util.NodeConfigResponse>newBuilder()
              .setType(io.grpc.MethodDescriptor.MethodType.UNARY)
              .setFullMethodName(generateFullMethodName(
                  "wavesenterprise.NodeInfoService", "NodeConfig"))
              .setSampledToLocalTracing(true)
              .setRequestMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  com.google.protobuf.Empty.getDefaultInstance()))
              .setResponseMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  com.wavesenterprise.protobuf.service.util.NodeConfigResponse.getDefaultInstance()))
                  .setSchemaDescriptor(new NodeInfoServiceMethodDescriptorSupplier("NodeConfig"))
                  .build();
          }
        }
     }
     return getNodeConfigMethod;
  }

  private static volatile io.grpc.MethodDescriptor<com.google.protobuf.Empty,
      com.wavesenterprise.protobuf.service.util.AddressWithPubKeyResponse> getNodeOwnerMethod;

  @io.grpc.stub.annotations.RpcMethod(
      fullMethodName = SERVICE_NAME + '/' + "NodeOwner",
      requestType = com.google.protobuf.Empty.class,
      responseType = com.wavesenterprise.protobuf.service.util.AddressWithPubKeyResponse.class,
      methodType = io.grpc.MethodDescriptor.MethodType.UNARY)
  public static io.grpc.MethodDescriptor<com.google.protobuf.Empty,
      com.wavesenterprise.protobuf.service.util.AddressWithPubKeyResponse> getNodeOwnerMethod() {
    io.grpc.MethodDescriptor<com.google.protobuf.Empty, com.wavesenterprise.protobuf.service.util.AddressWithPubKeyResponse> getNodeOwnerMethod;
    if ((getNodeOwnerMethod = NodeInfoServiceGrpc.getNodeOwnerMethod) == null) {
      synchronized (NodeInfoServiceGrpc.class) {
        if ((getNodeOwnerMethod = NodeInfoServiceGrpc.getNodeOwnerMethod) == null) {
          NodeInfoServiceGrpc.getNodeOwnerMethod = getNodeOwnerMethod = 
              io.grpc.MethodDescriptor.<com.google.protobuf.Empty, com.wavesenterprise.protobuf.service.util.AddressWithPubKeyResponse>newBuilder()
              .setType(io.grpc.MethodDescriptor.MethodType.UNARY)
              .setFullMethodName(generateFullMethodName(
                  "wavesenterprise.NodeInfoService", "NodeOwner"))
              .setSampledToLocalTracing(true)
              .setRequestMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  com.google.protobuf.Empty.getDefaultInstance()))
              .setResponseMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  com.wavesenterprise.protobuf.service.util.AddressWithPubKeyResponse.getDefaultInstance()))
                  .setSchemaDescriptor(new NodeInfoServiceMethodDescriptorSupplier("NodeOwner"))
                  .build();
          }
        }
     }
     return getNodeOwnerMethod;
  }

  /**
   * Creates a new async stub that supports all call types for the service
   */
  public static NodeInfoServiceStub newStub(io.grpc.Channel channel) {
    return new NodeInfoServiceStub(channel);
  }

  /**
   * Creates a new blocking-style stub that supports unary and streaming output calls on the service
   */
  public static NodeInfoServiceBlockingStub newBlockingStub(
      io.grpc.Channel channel) {
    return new NodeInfoServiceBlockingStub(channel);
  }

  /**
   * Creates a new ListenableFuture-style stub that supports unary calls on the service
   */
  public static NodeInfoServiceFutureStub newFutureStub(
      io.grpc.Channel channel) {
    return new NodeInfoServiceFutureStub(channel);
  }

  /**
   */
  public static abstract class NodeInfoServiceImplBase implements io.grpc.BindableService {

    /**
     */
    public void nodeConfig(com.google.protobuf.Empty request,
        io.grpc.stub.StreamObserver<com.wavesenterprise.protobuf.service.util.NodeConfigResponse> responseObserver) {
      asyncUnimplementedUnaryCall(getNodeConfigMethod(), responseObserver);
    }

    /**
     */
    public void nodeOwner(com.google.protobuf.Empty request,
        io.grpc.stub.StreamObserver<com.wavesenterprise.protobuf.service.util.AddressWithPubKeyResponse> responseObserver) {
      asyncUnimplementedUnaryCall(getNodeOwnerMethod(), responseObserver);
    }

    @java.lang.Override public final io.grpc.ServerServiceDefinition bindService() {
      return io.grpc.ServerServiceDefinition.builder(getServiceDescriptor())
          .addMethod(
            getNodeConfigMethod(),
            asyncUnaryCall(
              new MethodHandlers<
                com.google.protobuf.Empty,
                com.wavesenterprise.protobuf.service.util.NodeConfigResponse>(
                  this, METHODID_NODE_CONFIG)))
          .addMethod(
            getNodeOwnerMethod(),
            asyncUnaryCall(
              new MethodHandlers<
                com.google.protobuf.Empty,
                com.wavesenterprise.protobuf.service.util.AddressWithPubKeyResponse>(
                  this, METHODID_NODE_OWNER)))
          .build();
    }
  }

  /**
   */
  public static final class NodeInfoServiceStub extends io.grpc.stub.AbstractStub<NodeInfoServiceStub> {
    private NodeInfoServiceStub(io.grpc.Channel channel) {
      super(channel);
    }

    private NodeInfoServiceStub(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected NodeInfoServiceStub build(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      return new NodeInfoServiceStub(channel, callOptions);
    }

    /**
     */
    public void nodeConfig(com.google.protobuf.Empty request,
        io.grpc.stub.StreamObserver<com.wavesenterprise.protobuf.service.util.NodeConfigResponse> responseObserver) {
      asyncUnaryCall(
          getChannel().newCall(getNodeConfigMethod(), getCallOptions()), request, responseObserver);
    }

    /**
     */
    public void nodeOwner(com.google.protobuf.Empty request,
        io.grpc.stub.StreamObserver<com.wavesenterprise.protobuf.service.util.AddressWithPubKeyResponse> responseObserver) {
      asyncUnaryCall(
          getChannel().newCall(getNodeOwnerMethod(), getCallOptions()), request, responseObserver);
    }
  }

  /**
   */
  public static final class NodeInfoServiceBlockingStub extends io.grpc.stub.AbstractStub<NodeInfoServiceBlockingStub> {
    private NodeInfoServiceBlockingStub(io.grpc.Channel channel) {
      super(channel);
    }

    private NodeInfoServiceBlockingStub(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected NodeInfoServiceBlockingStub build(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      return new NodeInfoServiceBlockingStub(channel, callOptions);
    }

    /**
     */
    public com.wavesenterprise.protobuf.service.util.NodeConfigResponse nodeConfig(com.google.protobuf.Empty request) {
      return blockingUnaryCall(
          getChannel(), getNodeConfigMethod(), getCallOptions(), request);
    }

    /**
     */
    public com.wavesenterprise.protobuf.service.util.AddressWithPubKeyResponse nodeOwner(com.google.protobuf.Empty request) {
      return blockingUnaryCall(
          getChannel(), getNodeOwnerMethod(), getCallOptions(), request);
    }
  }

  /**
   */
  public static final class NodeInfoServiceFutureStub extends io.grpc.stub.AbstractStub<NodeInfoServiceFutureStub> {
    private NodeInfoServiceFutureStub(io.grpc.Channel channel) {
      super(channel);
    }

    private NodeInfoServiceFutureStub(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected NodeInfoServiceFutureStub build(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      return new NodeInfoServiceFutureStub(channel, callOptions);
    }

    /**
     */
    public com.google.common.util.concurrent.ListenableFuture<com.wavesenterprise.protobuf.service.util.NodeConfigResponse> nodeConfig(
        com.google.protobuf.Empty request) {
      return futureUnaryCall(
          getChannel().newCall(getNodeConfigMethod(), getCallOptions()), request);
    }

    /**
     */
    public com.google.common.util.concurrent.ListenableFuture<com.wavesenterprise.protobuf.service.util.AddressWithPubKeyResponse> nodeOwner(
        com.google.protobuf.Empty request) {
      return futureUnaryCall(
          getChannel().newCall(getNodeOwnerMethod(), getCallOptions()), request);
    }
  }

  private static final int METHODID_NODE_CONFIG = 0;
  private static final int METHODID_NODE_OWNER = 1;

  private static final class MethodHandlers<Req, Resp> implements
      io.grpc.stub.ServerCalls.UnaryMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ServerStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ClientStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.BidiStreamingMethod<Req, Resp> {
    private final NodeInfoServiceImplBase serviceImpl;
    private final int methodId;

    MethodHandlers(NodeInfoServiceImplBase serviceImpl, int methodId) {
      this.serviceImpl = serviceImpl;
      this.methodId = methodId;
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public void invoke(Req request, io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        case METHODID_NODE_CONFIG:
          serviceImpl.nodeConfig((com.google.protobuf.Empty) request,
              (io.grpc.stub.StreamObserver<com.wavesenterprise.protobuf.service.util.NodeConfigResponse>) responseObserver);
          break;
        case METHODID_NODE_OWNER:
          serviceImpl.nodeOwner((com.google.protobuf.Empty) request,
              (io.grpc.stub.StreamObserver<com.wavesenterprise.protobuf.service.util.AddressWithPubKeyResponse>) responseObserver);
          break;
        default:
          throw new AssertionError();
      }
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public io.grpc.stub.StreamObserver<Req> invoke(
        io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        default:
          throw new AssertionError();
      }
    }
  }

  private static abstract class NodeInfoServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoFileDescriptorSupplier, io.grpc.protobuf.ProtoServiceDescriptorSupplier {
    NodeInfoServiceBaseDescriptorSupplier() {}

    @java.lang.Override
    public com.google.protobuf.Descriptors.FileDescriptor getFileDescriptor() {
      return com.wavesenterprise.protobuf.service.util.UtilNodeInfoService.getDescriptor();
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.ServiceDescriptor getServiceDescriptor() {
      return getFileDescriptor().findServiceByName("NodeInfoService");
    }
  }

  private static final class NodeInfoServiceFileDescriptorSupplier
      extends NodeInfoServiceBaseDescriptorSupplier {
    NodeInfoServiceFileDescriptorSupplier() {}
  }

  private static final class NodeInfoServiceMethodDescriptorSupplier
      extends NodeInfoServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoMethodDescriptorSupplier {
    private final String methodName;

    NodeInfoServiceMethodDescriptorSupplier(String methodName) {
      this.methodName = methodName;
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.MethodDescriptor getMethodDescriptor() {
      return getServiceDescriptor().findMethodByName(methodName);
    }
  }

  private static volatile io.grpc.ServiceDescriptor serviceDescriptor;

  public static io.grpc.ServiceDescriptor getServiceDescriptor() {
    io.grpc.ServiceDescriptor result = serviceDescriptor;
    if (result == null) {
      synchronized (NodeInfoServiceGrpc.class) {
        result = serviceDescriptor;
        if (result == null) {
          serviceDescriptor = result = io.grpc.ServiceDescriptor.newBuilder(SERVICE_NAME)
              .setSchemaDescriptor(new NodeInfoServiceFileDescriptorSupplier())
              .addMethod(getNodeConfigMethod())
              .addMethod(getNodeOwnerMethod())
              .build();
        }
      }
    }
    return result;
  }
}

==> we-node-client-grpc-java-2.0.0-sources.jar: com/wavesenterprise/protobuf/service/util/NodeInfoServiceGrpc.java <==
package com.wavesenterprise.protobuf.service.util;

import static io.grpc.MethodDescriptor.generateFullMethodName;

/**
 */
@javax.annotation.Generated(
    value = "by gRPC proto compiler (version 1.64.0)",
    comments = "Source: util/util_node_info_service.proto")
@io.grpc.stub.annotations.GrpcGenerated
public final class NodeInfoServiceGrpc {

  private NodeInfoServiceGrpc() {}

  public static final java.lang.String SERVICE_NAME = "wavesenterprise.NodeInfoService";

  // Static method descriptors that strictly reflect the proto.
  private static volatile io.grpc.MethodDescriptor<com.google.protobuf.Empty,
      com.wavesenterprise.protobuf.service.util.NodeConfigResponse> getNodeConfigMethod;

  @io.grpc.stub.annotations.RpcMethod(
      fullMethodName = SERVICE_NAME + '/' + "NodeConfig",
      requestType = com.google.protobuf.Empty.class,
      responseType = com.wavesenterprise.protobuf.service.util.NodeConfigResponse.class,
      methodType = io.grpc.MethodDescriptor.MethodType.UNARY)
  public static io.grpc.MethodDescriptor<com.google.protobuf.Empty,
      com.wavesenterprise.protobuf.service.util.NodeConfigResponse> getNodeConfigMethod() {
    io.grpc.MethodDescriptor<com.google.protobuf.Empty, com.wavesenterprise.protobuf.service.util.NodeConfigResponse> getNodeConfigMethod;
    if ((getNodeConfigMethod = NodeInfoServiceGrpc.getNodeConfigMethod) == null) {
      synchronized (NodeInfoServiceGrpc.class) {
        if ((getNodeConfigMethod = NodeInfoServiceGrpc.getNodeConfigMethod) == null) {
          NodeInfoServiceGrpc.getNodeConfigMethod = getNodeConfigMethod =
              io.grpc.MethodDescriptor.<com.google.protobuf.Empty, com.wavesenterprise.protobuf.service.util.NodeConfigResponse>newBuilder()
              .setType(io.grpc.MethodDescriptor.MethodType.UNARY)
              .setFullMethodName(generateFullMethodName(SERVICE_NAME, "NodeConfig"))
              .setSampledToLocalTracing(true)
              .setRequestMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  com.google.protobuf.Empty.getDefaultInstance()))
              .setResponseMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  com.wavesenterprise.protobuf.service.util.NodeConfigResponse.getDefaultInstance()))
              .setSchemaDescriptor(new NodeInfoServiceMethodDescriptorSupplier("NodeConfig"))
              .build();
        }
      }
    }
    return getNodeConfigMethod;
  }

  private static volatile io.grpc.MethodDescriptor<com.google.protobuf.Empty,
      com.wavesenterprise.protobuf.service.util.AddressWithPubKeyResponse> getNodeOwnerMethod;

  @io.grpc.stub.annotations.RpcMethod(
      fullMethodName = SERVICE_NAME + '/' + "NodeOwner",
      requestType = com.google.protobuf.Empty.class,
      responseType = com.wavesenterprise.protobuf.service.util.AddressWithPubKeyResponse.class,
      methodType = io.grpc.MethodDescriptor.MethodType.UNARY)
  public static io.grpc.MethodDescriptor<com.google.protobuf.Empty,
      com.wavesenterprise.protobuf.service.util.AddressWithPubKeyResponse> getNodeOwnerMethod() {
    io.grpc.MethodDescriptor<com.google.protobuf.Empty, com.wavesenterprise.protobuf.service.util.AddressWithPubKeyResponse> getNodeOwnerMethod;
    if ((getNodeOwnerMethod = NodeInfoServiceGrpc.getNodeOwnerMethod) == null) {
      synchronized (NodeInfoServiceGrpc.class) {
        if ((getNodeOwnerMethod = NodeInfoServiceGrpc.getNodeOwnerMethod) == null) {
          NodeInfoServiceGrpc.getNodeOwnerMethod = getNodeOwnerMethod =
              io.grpc.MethodDescriptor.<com.google.protobuf.Empty, com.wavesenterprise.protobuf.service.util.AddressWithPubKeyResponse>newBuilder()
              .setType(io.grpc.MethodDescriptor.MethodType.UNARY)
              .setFullMethodName(generateFullMethodName(SERVICE_NAME, "NodeOwner"))
              .setSampledToLocalTracing(true)
              .setRequestMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  com.google.protobuf.Empty.getDefaultInstance()))
              .setResponseMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  com.wavesenterprise.protobuf.service.util.AddressWithPubKeyResponse.getDefaultInstance()))
              .setSchemaDescriptor(new NodeInfoServiceMethodDescriptorSupplier("NodeOwner"))
              .build();
        }
      }
    }
    return getNodeOwnerMethod;
  }

  /**
   * Creates a new async stub that supports all call types for the service
   */
  public static NodeInfoServiceStub newStub(io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<NodeInfoServiceStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<NodeInfoServiceStub>() {
        @java.lang.Override
        public NodeInfoServiceStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new NodeInfoServiceStub(channel, callOptions);
        }
      };
    return NodeInfoServiceStub.newStub(factory, channel);
  }

  /**
   * Creates a new blocking-style stub that supports unary and streaming output calls on the service
   */
  public static NodeInfoServiceBlockingStub newBlockingStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<NodeInfoServiceBlockingStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<NodeInfoServiceBlockingStub>() {
        @java.lang.Override
        public NodeInfoServiceBlockingStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new NodeInfoServiceBlockingStub(channel, callOptions);
        }
      };
    return NodeInfoServiceBlockingStub.newStub(factory, channel);
  }

  /**
   * Creates a new ListenableFuture-style stub that supports unary calls on the service
   */
  public static NodeInfoServiceFutureStub newFutureStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<NodeInfoServiceFutureStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<NodeInfoServiceFutureStub>() {
        @java.lang.Override
        public NodeInfoServiceFutureStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new NodeInfoServiceFutureStub(channel, callOptions);
        }
      };
    return NodeInfoServiceFutureStub.newStub(factory, channel);
  }

  /**
   */
  public interface AsyncService {

    /**
     */
    default void nodeConfig(com.google.protobuf.Empty request,
        io.grpc.stub.StreamObserver<com.wavesenterprise.protobuf.service.util.NodeConfigResponse> responseObserver) {
      io.grpc.stub.ServerCalls.asyncUnimplementedUnaryCall(getNodeConfigMethod(), responseObserver);
    }

    /**
     */
    default void nodeOwner(com.google.protobuf.Empty request,
        io.grpc.stub.StreamObserver<com.wavesenterprise.protobuf.service.util.AddressWithPubKeyResponse> responseObserver) {
      io.grpc.stub.ServerCalls.asyncUnimplementedUnaryCall(getNodeOwnerMethod(), responseObserver);
    }
  }

  /**
   * Base class for the server implementation of the service NodeInfoService.
   */
  public static abstract class NodeInfoServiceImplBase
      implements io.grpc.BindableService, AsyncService {

    @java.lang.Override public final io.grpc.ServerServiceDefinition bindService() {
      return NodeInfoServiceGrpc.bindService(this);
    }
  }

  /**
   * A stub to allow clients to do asynchronous rpc calls to service NodeInfoService.
   */
  public static final class NodeInfoServiceStub
      extends io.grpc.stub.AbstractAsyncStub<NodeInfoServiceStub> {
    private NodeInfoServiceStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected NodeInfoServiceStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new NodeInfoServiceStub(channel, callOptions);
    }

    /**
     */
    public void nodeConfig(com.google.protobuf.Empty request,
        io.grpc.stub.StreamObserver<com.wavesenterprise.protobuf.service.util.NodeConfigResponse> responseObserver) {
      io.grpc.stub.ClientCalls.asyncUnaryCall(
          getChannel().newCall(getNodeConfigMethod(), getCallOptions()), request, responseObserver);
    }

    /**
     */
    public void nodeOwner(com.google.protobuf.Empty request,
        io.grpc.stub.StreamObserver<com.wavesenterprise.protobuf.service.util.AddressWithPubKeyResponse> responseObserver) {
      io.grpc.stub.ClientCalls.asyncUnaryCall(
          getChannel().newCall(getNodeOwnerMethod(), getCallOptions()), request, responseObserver);
    }
  }

  /**
   * A stub to allow clients to do synchronous rpc calls to service NodeInfoService.
   */
  public static final class NodeInfoServiceBlockingStub
      extends io.grpc.stub.AbstractBlockingStub<NodeInfoServiceBlockingStub> {
    private NodeInfoServiceBlockingStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected NodeInfoServiceBlockingStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new NodeInfoServiceBlockingStub(channel, callOptions);
    }

    /**
     */
    public com.wavesenterprise.protobuf.service.util.NodeConfigResponse nodeConfig(com.google.protobuf.Empty request) {
      return io.grpc.stub.ClientCalls.blockingUnaryCall(
          getChannel(), getNodeConfigMethod(), getCallOptions(), request);
    }

    /**
     */
    public com.wavesenterprise.protobuf.service.util.AddressWithPubKeyResponse nodeOwner(com.google.protobuf.Empty request) {
      return io.grpc.stub.ClientCalls.blockingUnaryCall(
          getChannel(), getNodeOwnerMethod(), getCallOptions(), request);
    }
  }

  /**
   * A stub to allow clients to do ListenableFuture-style rpc calls to service NodeInfoService.
   */
  public static final class NodeInfoServiceFutureStub
      extends io.grpc.stub.AbstractFutureStub<NodeInfoServiceFutureStub> {
    private NodeInfoServiceFutureStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected NodeInfoServiceFutureStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new NodeInfoServiceFutureStub(channel, callOptions);
    }

    /**
     */
    public com.google.common.util.concurrent.ListenableFuture<com.wavesenterprise.protobuf.service.util.NodeConfigResponse> nodeConfig(
        com.google.protobuf.Empty request) {
      return io.grpc.stub.ClientCalls.futureUnaryCall(
          getChannel().newCall(getNodeConfigMethod(), getCallOptions()), request);
    }

    /**
     */
    public com.google.common.util.concurrent.ListenableFuture<com.wavesenterprise.protobuf.service.util.AddressWithPubKeyResponse> nodeOwner(
        com.google.protobuf.Empty request) {
      return io.grpc.stub.ClientCalls.futureUnaryCall(
          getChannel().newCall(getNodeOwnerMethod(), getCallOptions()), request);
    }
  }

  private static final int METHODID_NODE_CONFIG = 0;
  private static final int METHODID_NODE_OWNER = 1;

  private static final class MethodHandlers<Req, Resp> implements
      io.grpc.stub.ServerCalls.UnaryMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ServerStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ClientStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.BidiStreamingMethod<Req, Resp> {
    private final AsyncService serviceImpl;
    private final int methodId;

    MethodHandlers(AsyncService serviceImpl, int methodId) {
      this.serviceImpl = serviceImpl;
      this.methodId = methodId;
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public void invoke(Req request, io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        case METHODID_NODE_CONFIG:
          serviceImpl.nodeConfig((com.google.protobuf.Empty) request,
              (io.grpc.stub.StreamObserver<com.wavesenterprise.protobuf.service.util.NodeConfigResponse>) responseObserver);
          break;
        case METHODID_NODE_OWNER:
          serviceImpl.nodeOwner((com.google.protobuf.Empty) request,
              (io.grpc.stub.StreamObserver<com.wavesenterprise.protobuf.service.util.AddressWithPubKeyResponse>) responseObserver);
          break;
        default:
          throw new AssertionError();
      }
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public io.grpc.stub.StreamObserver<Req> invoke(
        io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        default:
          throw new AssertionError();
      }
    }
  }

  public static final io.grpc.ServerServiceDefinition bindService(AsyncService service) {
    return io.grpc.ServerServiceDefinition.builder(getServiceDescriptor())
        .addMethod(
          getNodeConfigMethod(),
          io.grpc.stub.ServerCalls.asyncUnaryCall(
            new MethodHandlers<
              com.google.protobuf.Empty,
              com.wavesenterprise.protobuf.service.util.NodeConfigResponse>(
                service, METHODID_NODE_CONFIG)))
        .addMethod(
          getNodeOwnerMethod(),
          io.grpc.stub.ServerCalls.asyncUnaryCall(
            new MethodHandlers<
              com.google.protobuf.Empty,
              com.wavesenterprise.protobuf.service.util.AddressWithPubKeyResponse>(
                service, METHODID_NODE_OWNER)))
        .build();
  }

  private static abstract class NodeInfoServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoFileDescriptorSupplier, io.grpc.protobuf.ProtoServiceDescriptorSupplier {
    NodeInfoServiceBaseDescriptorSupplier() {}

    @java.lang.Override
    public com.google.protobuf.Descriptors.FileDescriptor getFileDescriptor() {
      return com.wavesenterprise.protobuf.service.util.UtilNodeInfoService.getDescriptor();
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.ServiceDescriptor getServiceDescriptor() {
      return getFileDescriptor().findServiceByName("NodeInfoService");
    }
  }

  private static final class NodeInfoServiceFileDescriptorSupplier
      extends NodeInfoServiceBaseDescriptorSupplier {
    NodeInfoServiceFileDescriptorSupplier() {}
  }

  private static final class NodeInfoServiceMethodDescriptorSupplier
      extends NodeInfoServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoMethodDescriptorSupplier {
    private final java.lang.String methodName;

    NodeInfoServiceMethodDescriptorSupplier(java.lang.String methodName) {
      this.methodName = methodName;
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.MethodDescriptor getMethodDescriptor() {
      return getServiceDescriptor().findMethodByName(methodName);
    }
  }

  private static volatile io.grpc.ServiceDescriptor serviceDescriptor;

  public static io.grpc.ServiceDescriptor getServiceDescriptor() {
    io.grpc.ServiceDescriptor result = serviceDescriptor;
    if (result == null) {
      synchronized (NodeInfoServiceGrpc.class) {
        result = serviceDescriptor;
        if (result == null) {
          serviceDescriptor = result = io.grpc.ServiceDescriptor.newBuilder(SERVICE_NAME)
              .setSchemaDescriptor(new NodeInfoServiceFileDescriptorSupplier())
              .addMethod(getNodeConfigMethod())
              .addMethod(getNodeOwnerMethod())
              .build();
        }
      }
    }
    return result;
  }
}
